==> dokuwiki-2012.01.25.tgz: dokuwiki/lib/plugins/usermanager/lang/sk/lang.php <==
<?php
/**
 * Slovak language file
 *
 * @author Ondrej Végh <ov@vsieti.sk>
 * @author Michal Mesko <michal.mesko@gmail.com>
 * @author exusik@gmail.com
 * @author Martin Michalek <michalek.dev@gmail.com>
 */
$lang['menu']                  = 'Správa používateľov';
$lang['noauth']                = '(autentifikácia užívateľov nie je dostupná)';
$lang['nosupport']             = '(správa užívateľov nie je podporovaná)';
$lang['badauth']               = 'neplatný autorizačný mechanizmus';
$lang['user_id']               = 'Užívateľ';
$lang['user_pass']             = 'Heslo';
$lang['user_name']             = 'Skutočné meno';
$lang['user_mail']             = 'Email';
$lang['user_groups']           = 'Skupiny';
$lang['field']                 = 'Pole';
$lang['value']                 = 'Hodnota';
$lang['add']                   = 'Pridať';
$lang['delete']                = 'Zmazať';
$lang['delete_selected']       = 'Zmazať vybrané';
$lang['edit']                  = 'Zmeniť';
$lang['edit_prompt']           = 'Zmeniť tohoto užívateľa';
$lang['modify']                = 'Uložiť zmeny';
$lang['search']                = 'Hľadať';
$lang['search_prompt']         = 'Vykonať vyhľadávanie';
$lang['clear']                 = 'Vynulovať vyhľadávací filter';
$lang['filter']                = 'Filter';
$lang['summary']               = 'Zobrazenie užívateľov %1$d-%2$d z %3$d nájdených. %4$d užívateľov celkom.';
$lang['nonefound']             = 'Žiadni užívatelia nenájdení. %d užívateľov celkom.';
$lang['delete_ok']             = '%d užívateľov zmazaných';
$lang['delete_fail']           = '%d chýb vymazania.';
$lang['update_ok']             = 'Užívateľ úspešne zmenený';
$lang['update_fail']           = 'Chyba zmeny užívateľa';
$lang['update_exists']         = 'Chyba zmeny užívateľa, užívateľské meno (%s) už existuje (iné zmeny budú zaznamenané).';
$lang['start']                 = 'prvé';
$lang['prev']                  = 'predošlé';
$lang['next']                  = 'ďalšie';
$lang['last']                  = 'posledné';
$lang['edit_usermissing']      = 'Vybraný užívateľ nebol nájdený, mohol byť zmazaný alebo zmenený iným spôsobom.';
$lang['user_notify']           = 'Upozorniť užívateľa';
$lang['note_notify']           = 'Notifikačné e-maily iba vtedy, ak dostane užívateľ nové heslo';
$lang['note_group']            = 'Noví užívatelia budú pridaní do východzej skupiny (%s), ak nie je pre nich špecifikovaná iná skupina.';
$lang['note_pass']             = 'Heslo bude vygenerované automaticky, ak bude pole prázdne a je zapnutá notifikácia používateľa.';
$lang['add_ok']                = 'Používateľ úspešne pridaný';
$lang['add_fail']              = 'Pridávanie užívateľa nebolo úspešné';
$lang['notify_ok']             = 'Notifikačný e-mail bol poslaný';
$lang['notify_fail']           = 'Notifikačný e-mail nemohol byť poslaný';

==> dokuwiki-2016.06.26a.tgz: dokuwiki/lib/plugins/usermanager/lang/sk/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Ondrej Végh <ov@vsieti.sk>
 * @author Michal Mesko <michal.mesko@gmail.com>
 * @author exusik@gmail.com
 * @author Martin Michalek <michalek.dev@gmail.com>
 */
$lang['menu']                  = 'Správa používateľov';
$lang['noauth']                = '(autentifikácia užívateľov nie je dostupná)';
$lang['nosupport']             = '(správa užívateľov nie je podporovaná)';
$lang['badauth']               = 'neplatný autorizačný mechanizmus';
$lang['user_id']               = 'Užívateľ';
$lang['user_pass']             = 'Heslo';
$lang['user_name']             = 'Skutočné meno';
$lang['user_mail']             = 'Email';
$lang['user_groups']           = 'Skupiny';
$lang['field']                 = 'Pole';
$lang['value']                 = 'Hodnota';
$lang['add']                   = 'Pridať';
$lang['delete']                = 'Zmazať';
$lang['delete_selected']       = 'Zmazať vybrané';
$lang['edit']                  = 'Zmeniť';
$lang['edit_prompt']           = 'Zmeniť tohoto užívateľa';
$lang['modify']                = 'Uložiť zmeny';
$lang['search']                = 'Hľadať';
$lang['search_prompt']         = 'Vykonať vyhľadávanie';
$lang['clear']                 = 'Vynulovať vyhľadávací filter';
$lang['filter']                = 'Filter';
$lang['export_all']            = 'Export všetkých používateľov (CSV)';
$lang['export_filtered']       = 'Export zoznamu používateľov na základe filtra (CSV)';
$lang['import']                = 'Import nových používateľov';
$lang['line']                  = 'Riadok č.';
$lang['error']                 = 'Chybová správa';
$lang['summary']               = 'Zobrazenie užívateľov %1$d-%2$d z %3$d nájdených. %4$d užívateľov celkom.';
$lang['nonefound']             = 'Žiadni užívatelia nenájdení. %d užívateľov celkom.';
$lang['delete_ok']             = '%d užívateľov zmazaných';
$lang['delete_fail']           = '%d chýb vymazania.';
$lang['update_ok']             = 'Užívateľ úspešne zmenený';
$lang['update_fail']           = 'Chyba zmeny užívateľa';
$lang['update_exists']         = 'Chyba zmeny mena používateľa, používateľské meno (%s) už existuje (iné zmeny budú zaznamenané).';
$lang['start']                 = 'prvé';
$lang['prev']                  = 'predošlé';
$lang['next']                  = 'ďalšie';
$lang['last']                  = 'posledné';
$lang['edit_usermissing']      = 'Vybraný užívateľ nebol nájdený, mohol byť zmazaný alebo zmenený iným spôsobom.';
$lang['user_notify']           = 'Upozorniť užívateľa';
$lang['note_notify']           = 'Notifikačné e-maily iba vtedy, ak dostane užívateľ nové heslo';
$lang['note_group']            = 'Noví užívatelia budú pridaní do východzej skupiny (%s), ak nie je pre nich špecifikovaná iná skupina.';
$lang['note_pass']             = 'Heslo bude vygenerované automaticky, ak bude pole prázdne a je zapnutá notifikácia používateľa.';
$lang['add_ok']                = 'Používateľ úspešne pridaný';
$lang['add_fail']              = 'Pridanie používateľa bolo neúspešné';
$lang['notify_ok']             = 'Notifikačný e-mail bol poslaný';
$lang['notify_fail']           = 'Notifikačný e-mail nemohol byť poslaný';
$lang['import_userlistcsv']    = 'Súbor so zoznamov používateľov (CSV):';
$lang['import_header']         = 'Chyby pri poslednom importe';
$lang['import_success_count']  = 'Import používateľov: %d nájdených, %d úspešne importovaných.';
$lang['import_failure_count']  = 'Import používateľov: %d neúspešných. Problámy  vypísané nižšie.';
$lang['import_error_fields']   = 'Neúplné záznamy, %d nájdené, 4 požadované.';
$lang['import_error_baduserid'] = 'Chýba ID používateľa';
$lang['import_error_badname']  = 'Nesprávne meno';
$lang['import_error_badmail']  = 'Nesprávna emailová adresa';
$lang['import_error_upload']   = 'Import neúspešný. CSV súbor nemohol byť nahraný alebo je prázdny.';
$lang['import_error_readfail'] = 'Import neúspešný. Nie je možné prečítať nahraný súbor.';
$lang['import_error_create']   = 'Nie je možné vytvoriť pouzívateľa';
$lang['import_notify_fail']    = 'Správa nemohla byť zaslaná importovanému používatelovi, %s s emailom %s.';
$lang['import_downloadfailures'] = 'Stiahnuť chyby vo formáte CSV za účelom opravy';
